package net.sf.itcb.common.web.portal;

import java.util.Locale;
import java.util.Map;

import net.sf.itcb.common.web.exceptions.WebItcbException;
import net.sf.itcb.common.web.exceptions.WebItcbExceptionMappingErrors;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.context.MessageSource;
import org.springframework.context.ApplicationContextAware;
import org.springframework.context.ApplicationContext;

/**
 * This class defines in which portal the portlet is launched and give the portalAdapter associated
 * Mapping is done by the map <code>portalAdapters</code> injected by Spring.
 * 
 * @author Pierre Le Roux
 */
public class PortalAdapterProvider<T> implements ApplicationContextAware {
	
	protected PortalAdapter<T> selectedPortalAdapter;
	
	protected MessageSource itcbPortletMessageSource; 
	
	protected ApplicationContext applicationContext;
	
	protected final Logger log = LoggerFactory.getLogger(getClass());
	
	public void setApplicationContext(ApplicationContext applicationContext) {
		this.applicationContext=applicationContext;
	}
	
	public void setItcbPortletMessageSource(MessageSource messageSource) {
		itcbPortletMessageSource = messageSource;
	}

	@SuppressWarnings({ "unchecked", "rawtypes" })
	public PortalAdapter<T> getPortalAdapter(T request) {
		if(selectedPortalAdapter != null) {
			return selectedPortalAdapter;
		}
		
		Map<String, PortalAdapter> portalAdapters = applicationContext.getBeansOfType(PortalAdapter.class);
		PortalAdapter<T> portalAdapter = portalAdapters.get(request.getClass().getName());
		if(portalAdapter != null) {
			selectedPortalAdapter= portalAdapter;
			return portalAdapter;
		}
		else {
			throw new WebItcbException(WebItcbExceptionMappingErrors.COMMON_PORTLET_NO_PORTAL_PROVIDER, itcbPortletMessageSource.getMessage("common.portlet.exception.no.portal.provider", null, Locale.getDefault()));
		}
		
	}
	
	

}
